const express = require('express')
const socketio = require('socket.io')
const sense = require('sense-hat-led').sync
const app = express()
const server = app.listen(3000, '0.0.0.0', () => console.log('server is running'))
const io = socketio(server)
app.use(express.static('public'))
sense.setRotation(180)
sense.lowLight = true

const blue = [0, 0, 255]
const leds = [
    [0, 0, 0, 0, 0, 0, 0, 0],
    [0, 0, 0, 0, 0, 0, 0, 0],
    [0, 0, 0, 0, 0, 0, 0, 0],
    [0, 0, 0, 0, 0, 0, 0, 0],
    [0, 0, 0, 0, 0, 0, 0, 0],
    [0, 0, 0, 0, 0, 0, 0, 0],
    [0, 0, 0, 0, 0, 0, 0, 0],
    [0, 0, 0, 0, 0, 0, 0, 0],
]
read_all_leds()

io.on('connection', (client) => {
    client.emit('leds', leds)
    client.on('action', ({ action, x, y }) => {
        console.log({ action, x, y })
        switch (action) {
            case 'on':
                sense.setPixel(Number(x), Number(y), blue)
                leds[y][x] = 1
                break
            case 'off':
                sense.setPixel(Number(x), Number(y), [0, 0, 0])
                leds[y][x] = 0
                break
            case 'hello':
                sense.flashMessage('HELLO', 1, blue)
                sense.clear()
                read_all_leds(true)
                break
            case 'flash':
                sense.clear([255, 255, 255])
                setTimeout(sense.clear, 100)
                read_all_leds(true)
                break
            case 'clear':
                sense.clear()
                read_all_leds(true)
                break
            case 'temp':
                read_all_leds()
                break
            default:
                break
        }
        io.emit('leds', leds)
    })
})

function read_all_leds(zero = false) {
    const pixels = sense.getPixels()
    for (let y = 0; y < 8; y++) {
        for (let x = 0; x < 8; x++) {
            leds[y][x] = zero || sense.getPixel(x, y)[2] == 0 ? 0 : 1
        }
    }
}
